@@ -13,7 +13,7 @@ Usage::
 """
 import sys
 from datetime import datetime
-from typing import Any, Dict, List
+from typing import Any, Dict, List, Sequence
 
 from .literals import (
     ArtifactNamespaceType,
@@ -205,7 +205,7 @@ __all__ = (
 BatchDeleteBuildsInputRequestTypeDef = TypedDict(
     "BatchDeleteBuildsInputRequestTypeDef",
     {
-        "ids": List[str],
+        "ids": Sequence[str],
     },
 )
 
@@ -221,7 +221,7 @@ BatchDeleteBuildsOutputTypeDef = TypedDict(
 BatchGetBuildBatchesInputRequestTypeDef = TypedDict(
     "BatchGetBuildBatchesInputRequestTypeDef",
     {
-        "ids": List[str],
+        "ids": Sequence[str],
     },
 )
 
@@ -237,7 +237,7 @@ BatchGetBuildBatchesOutputTypeDef = TypedDict(
 BatchGetBuildsInputRequestTypeDef = TypedDict(
     "BatchGetBuildsInputRequestTypeDef",
     {
-        "ids": List[str],
+        "ids": Sequence[str],
     },
 )
 
@@ -253,7 +253,7 @@ BatchGetBuildsOutputTypeDef = TypedDict(
 BatchGetProjectsInputRequestTypeDef = TypedDict(
     "BatchGetProjectsInputRequestTypeDef",
     {
-        "names": List[str],
+        "names": Sequence[str],
     },
 )
 
@@ -269,7 +269,7 @@ BatchGetProjectsOutputTypeDef = TypedDict(
 BatchGetReportGroupsInputRequestTypeDef = TypedDict(
     "BatchGetReportGroupsInputRequestTypeDef",
     {
-        "reportGroupArns": List[str],
+        "reportGroupArns": Sequence[str],
     },
 )
 
@@ -285,7 +285,7 @@ BatchGetReportGroupsOutputTypeDef = TypedDict(
 BatchGetReportsInputRequestTypeDef = TypedDict(
     "BatchGetReportsInputRequestTypeDef",
     {
-        "reportArns": List[str],
+        "reportArns": Sequence[str],
     },
 )
 
@@ -539,19 +539,19 @@ _OptionalCreateProjectInputRequestTypeDef = TypedDict(
     "_OptionalCreateProjectInputRequestTypeDef",
     {
         "description": str,
-        "secondarySources": List["ProjectSourceTypeDef"],
+        "secondarySources": Sequence["ProjectSourceTypeDef"],
         "sourceVersion": str,
-        "secondarySourceVersions": List["ProjectSourceVersionTypeDef"],
-        "secondaryArtifacts": List["ProjectArtifactsTypeDef"],
+        "secondarySourceVersions": Sequence["ProjectSourceVersionTypeDef"],
+        "secondaryArtifacts": Sequence["ProjectArtifactsTypeDef"],
         "cache": "ProjectCacheTypeDef",
         "timeoutInMinutes": int,
         "queuedTimeoutInMinutes": int,
         "encryptionKey": str,
-        "tags": List["TagTypeDef"],
+        "tags": Sequence["TagTypeDef"],
         "vpcConfig": "VpcConfigTypeDef",
         "badgeEnabled": bool,
         "logsConfig": "LogsConfigTypeDef",
-        "fileSystemLocations": List["ProjectFileSystemLocationTypeDef"],
+        "fileSystemLocations": Sequence["ProjectFileSystemLocationTypeDef"],
         "buildBatchConfig": "ProjectBuildBatchConfigTypeDef",
         "concurrentBuildLimit": int,
     },
@@ -584,7 +584,7 @@ _RequiredCreateReportGroupInputRequestTypeDef = TypedDict(
 _OptionalCreateReportGroupInputRequestTypeDef = TypedDict(
     "_OptionalCreateReportGroupInputRequestTypeDef",
     {
-        "tags": List["TagTypeDef"],
+        "tags": Sequence["TagTypeDef"],
     },
     total=False,
 )
@@ -614,7 +614,7 @@ _OptionalCreateWebhookInputRequestTypeDef = TypedDict(
     "_OptionalCreateWebhookInputRequestTypeDef",
     {
         "branchFilter": str,
-        "filterGroups": List[List["WebhookFilterTypeDef"]],
+        "filterGroups": Sequence[Sequence["WebhookFilterTypeDef"]],
         "buildType": WebhookBuildTypeType,
     },
     total=False,
@@ -1635,12 +1635,12 @@ _RequiredStartBuildBatchInputRequestTypeDef = TypedDict(
 _OptionalStartBuildBatchInputRequestTypeDef = TypedDict(
     "_OptionalStartBuildBatchInputRequestTypeDef",
     {
-        "secondarySourcesOverride": List["ProjectSourceTypeDef"],
-        "secondarySourcesVersionOverride": List["ProjectSourceVersionTypeDef"],
+        "secondarySourcesOverride": Sequence["ProjectSourceTypeDef"],
+        "secondarySourcesVersionOverride": Sequence["ProjectSourceVersionTypeDef"],
         "sourceVersion": str,
         "artifactsOverride": "ProjectArtifactsTypeDef",
-        "secondaryArtifactsOverride": List["ProjectArtifactsTypeDef"],
-        "environmentVariablesOverride": List["EnvironmentVariableTypeDef"],
+        "secondaryArtifactsOverride": Sequence["ProjectArtifactsTypeDef"],
+        "environmentVariablesOverride": Sequence["EnvironmentVariableTypeDef"],
         "sourceTypeOverride": SourceTypeType,
         "sourceLocationOverride": str,
         "sourceAuthOverride": "SourceAuthTypeDef",
@@ -1693,12 +1693,12 @@ _RequiredStartBuildInputRequestTypeDef = TypedDict(
 _OptionalStartBuildInputRequestTypeDef = TypedDict(
     "_OptionalStartBuildInputRequestTypeDef",
     {
-        "secondarySourcesOverride": List["ProjectSourceTypeDef"],
-        "secondarySourcesVersionOverride": List["ProjectSourceVersionTypeDef"],
+        "secondarySourcesOverride": Sequence["ProjectSourceTypeDef"],
+        "secondarySourcesVersionOverride": Sequence["ProjectSourceVersionTypeDef"],
         "sourceVersion": str,
         "artifactsOverride": "ProjectArtifactsTypeDef",
-        "secondaryArtifactsOverride": List["ProjectArtifactsTypeDef"],
-        "environmentVariablesOverride": List["EnvironmentVariableTypeDef"],
+        "secondaryArtifactsOverride": Sequence["ProjectArtifactsTypeDef"],
+        "environmentVariablesOverride": Sequence["EnvironmentVariableTypeDef"],
         "sourceTypeOverride": SourceTypeType,
         "sourceLocationOverride": str,
         "sourceAuthOverride": "SourceAuthTypeDef",
@@ -1825,22 +1825,22 @@ _OptionalUpdateProjectInputRequestTypeDef = TypedDict(
     {
         "description": str,
         "source": "ProjectSourceTypeDef",
-        "secondarySources": List["ProjectSourceTypeDef"],
+        "secondarySources": Sequence["ProjectSourceTypeDef"],
         "sourceVersion": str,
-        "secondarySourceVersions": List["ProjectSourceVersionTypeDef"],
+        "secondarySourceVersions": Sequence["ProjectSourceVersionTypeDef"],
         "artifacts": "ProjectArtifactsTypeDef",
-        "secondaryArtifacts": List["ProjectArtifactsTypeDef"],
+        "secondaryArtifacts": Sequence["ProjectArtifactsTypeDef"],
         "cache": "ProjectCacheTypeDef",
         "environment": "ProjectEnvironmentTypeDef",
         "serviceRole": str,
         "timeoutInMinutes": int,
         "queuedTimeoutInMinutes": int,
         "encryptionKey": str,
-        "tags": List["TagTypeDef"],
+        "tags": Sequence["TagTypeDef"],
         "vpcConfig": "VpcConfigTypeDef",
         "badgeEnabled": bool,
         "logsConfig": "LogsConfigTypeDef",
-        "fileSystemLocations": List["ProjectFileSystemLocationTypeDef"],
+        "fileSystemLocations": Sequence["ProjectFileSystemLocationTypeDef"],
         "buildBatchConfig": "ProjectBuildBatchConfigTypeDef",
         "concurrentBuildLimit": int,
     },
@@ -1905,7 +1905,7 @@ _OptionalUpdateReportGroupInputRequestTypeDef = TypedDict(
     "_OptionalUpdateReportGroupInputRequestTypeDef",
     {
         "exportConfig": "ReportExportConfigTypeDef",
-        "tags": List["TagTypeDef"],
+        "tags": Sequence["TagTypeDef"],
     },
     total=False,
 )
@@ -1936,7 +1936,7 @@ _OptionalUpdateWebhookInputRequestTypeDef = TypedDict(
     {
         "branchFilter": str,
         "rotateSecret": bool,
-        "filterGroups": List[List["WebhookFilterTypeDef"]],
+        "filterGroups": Sequence[Sequence["WebhookFilterTypeDef"]],
         "buildType": WebhookBuildTypeType,
     },
     total=False,
